local MAJOR_VERSION = "LibDogTag-2.0"
local MINOR_VERSION = tonumber(("$Revision: 59954 $"):match("%d+")) or 0

if MINOR_VERSION > _G.DogTag_MINOR_VERSION then
	_G.DogTag_MINOR_VERSION = MINOR_VERSION
end

DogTag_funcs[#DogTag_funcs+1] = function()

local L = DogTag.L

local BabbleSpell
DogTag:AddAddonFinder("AceLibrary", "Babble-Spell-2.2", function(v) BabbleSpell = v end)

DogTag:AddTag("DruidForm", {
	function(data)
		if not BabbleSpell then
			return ([[local _,c = UnitClass(${unit})
			if c == "DRUID" then
				local power = UnitPowerType(${unit})
				if power == 1 then
					value = %q
				elseif power == 3 then
					value = %q
				end
			end]]):format(L["Bear"], L["Cat"]), 'globals', "UNIT_DISPLAYPOWER"
		else
			return ([[local _,c = UnitClass(${unit})
			if c == "DRUID" then
				local power = UnitPowerType(${unit})
				if power == 1 then
					value = %q
				elseif power == 3 then
					value = %q
				else
					local auras = DogTag___currentAuras[${unit}]
					if auras[%q] then
						value = %q
					elseif auras[%q] then
						value = %q
					elseif auras[%q] or auras[%q] then
						value = %q
					elseif auras[%q] then
						value = %q
					elseif auras[%q] and auras[%q] >= 2 then
						value = %q
					end
				end
			end]]):format(L["Bear"], L["Cat"], BabbleSpell["Moonkin Form"], L["Moonkin"], BabbleSpell["Aquatic Form"], L["Aquatic"], BabbleSpell["Flight Form"], BabbleSpell["Swift Flight Form"], L["Flight"], BabbleSpell["Travel Form"], L["Travel"], BabbleSpell["Tree of Life"], BabbleSpell["Tree of Life"], L["Tree"]), 'events', (";"):join("UNIT_DISPLAYPOWER", BabbleSpell["Moonkin Form"], BabbleSpell["Aquatic Form"], BabbleSpell["Flight Form"], BabbleSpell["Swift Flight Form"], BabbleSpell["Travel Form"], BabbleSpell["Tree of Life"])
		end
	end,
	ret = "string;nil",
	globals = "UnitClass;UnitPowerType;DogTag.__currentAuras",
	doc = L["Return the shapeshift form which unit is in if unit is a druid"],
	example = ('[DruidForm] => %q; [DruidForm] => %q; [DruidForm] => ""'):format(L["Bear"], L["Cat"]),
	category = L["Auras"]
})

DogTag:AddTag("ShortDruidForm", {
	alias = "DruidForm:ShortDruidForm",
	doc = L["Return the shortened shapeshift form which unit is in if unit is a druid"],
	example = ('[ShortDruidForm] => %q; [ShortDruidForm] => %q; [ShortDruidForm] => ""'):format(L["Bear_short"], L["Cat_short"]),
	category = L["Auras"]
})

DogTag:AddTag("NumDebuffs", {
	[=[value = DogTag___currentNumDebuffs[${unit}]]=],
	ret = "number",
	globals = "DogTag.__currentNumDebuffs",
	events = "NumDebuffs",
	doc = L["Return the number of debuffs that unit has"],
	example = '[NumDebuffs] => "5"; [NumDebuffs] => "40"',
	category = L["Auras"]
})

DogTag:AddTag("HasAura", {
	function(data)
		if data.arg:find("%[") and data.arg:find("%]") then
			return [[value = "HasAura cannot support dynamic arguments."]]
		end
		if BabbleSpell then
			local arg = data.arg
			local localized = BabbleSpell:HasTranslation(arg)
			if localized then -- if arg is English
				arg = BabbleSpell[arg]
			end
			return ([[value = DogTag___currentAuras[${unit}][%q] and %q]]):format(arg, arg), 'events', arg
		else
			return [[value = DogTag___currentAuras[${unit}][${arg}] and ${arg}]], 'events', data.arg
		end
	end,
	arg = "string",
	ret = "string;nil",
	globals = "DogTag.__currentAuras",
	doc = L["Return the aura name if unit has the aura argument"],
	example = ('[HasAura(Shadowform)] => %q; [HasAura(Shadowform)] => ""'):format("Shadowform"),
	category = L["Auras"]
})

DogTag:AddTag("IsShadowform", {
	alias = "HasAura(Shadowform)",
	doc = L["Return Shadowform if the unit has the shadowform buff"],
	example = '[IsShadowform] => "Shadowform"; [IsShadowform] => ""',
	category = L["Auras"]
})

DogTag:AddTag("IsFeignedDeath", {
	function(data)
		if BabbleSpell then
			return ([[value = UnitIsFeignDeath(${unit}) and %q]]):format(BabbleSpell["Feign Death"])
		else
			return ([[value = UnitIsFeignDeath(${unit}) and %q]]):format(L["Feigned Death"])
		end
	end,
	ret = "string;nil",
	globals = "UnitIsFeignDeath",
	doc = L["Return Feigned Death if unit is currently feigning death"],
	example = ('[IsFeignedDeath] => %q; [IsFeignedDeath] => ""'):format(L["Feigned Death"]),
	category = L["Auras"]
})

DogTag:AddTag("IsStealthed", {
	alias = ("HasAura(Stealth):HasAura(Shadowmeld):HasAura(Prowl)?Text(%s)"):format(L["Stealthed"]),
	doc = L["Return Stealthed if the unit is stealthed in some way"],
	example = ('[IsStealthed] => %q; [IsStealthed] => ""'):format(L["Stealthed"]),
	category = L["Auras"]
})

DogTag:AddTag("HasShieldWall", {
	alias = "HasAura(Shield Wall)",
	doc = L["Return Shield Wall if the unit has the Shield Wall buff"],
	example = ('[HasShieldWall] => %q; [HasShieldWall] => ""'):format("Shield Wall"),
	category = L["Auras"]
})

DogTag:AddTag("HasLastStand", {
	alias = "HasAura(Last Stand)",
	doc = L["Return Last Stand if the unit has the Last Stand buff"],
	example = ('[HasLastStand] => %q; [HasLastStand] => ""'):format("Last Stand"),
	category = L["Auras"]
})

DogTag:AddTag("HasSoulstone", {
	alias = ("HasAura(Soulstone):HasAura(Soulstone Resurrection)?Text(%q)"):format(L["Soulstoned"]),
	doc = L["Return Soulstoned if the unit has the Soulstone buff"],
	example = ('[HasSoulstone] => %q; [HasSoulstone] => ""'):format(L["Soulstoned"]),
	category = L["Auras"]
})

DogTag:AddTag("HasMisdirection", {
	alias = "HasAura(Misdirection)",
	doc = L["Return Misdirection if the unit has the Misdirection buff"],
	example = ('[HasMisdirection] => %q; [HasMisdirection] => ""'):format("Misdirection"),
	category = L["Auras"]
})

DogTag:AddTag("HasIceBlock", {
	alias = "HasAura(Ice Block)",
	doc = L["Return Ice Block if the unit has the Ice Block buff"],
	example = ('[HasIceBlock] => %q; [HasMisdirection] => ""'):format("Ice Block"),
	category = L["Auras"]
})

DogTag:AddTag("HasInvisibility", {
	alias = "HasAura(Invisibility)",
	doc = L["Return Invisibility if the unit has the Invisibility buff"],
	example = ('[HasInvisibility] => %q; [HasInvisibility] => ""'):format("Invisibility"),
	category = L["Auras"]
})

DogTag:AddTag("HasDivineIntervention", {
	alias = "HasAura(Divine Intervention)",
	doc = L["Return Divine Intervention if the unit has the Divine Intervention buff"],
	example = ('[HasDivineIntervention] => %q; [HasDivineIntervention] => ""'):format("Divine Intervention"),
	category = L["Auras"]
})

DogTag:AddTag("HasDebuffType", {
	function(data)
		if data.arg:find("%[") and data.arg:find("%]") then
			return [[value = "HasDebuffType cannot support dynamic arguments."]]
		end
		return [[value = DogTag___currentDebuffTypes[${unit}][${arg}] and ${arg}]], 'events', data.arg
	end,
	arg = "string",
	ret = "string;nil",
	globals = "DogTag.__currentDebuffTypes",
	doc = L["Return True if unit is has a debuff of type argument"],
	example = '[HasDebuffType(Poison)] => "True"; [HasDebuffType(Poison)] => ""',
	category = L["Auras"]
})

DogTag:AddTag("HasMagicDebuff", {
	alias = "HasDebuffType(Magic)",
	doc = L["Return Magic if the unit has a Magic debuff"],
	example = ('[HasMagicDebuff] => %q; [HasMagicDebuff] => ""'):format("Magic"),
	category = L["Auras"]
})

DogTag:AddTag("HasCurseDebuff", {
	alias = "HasDebuffType(Curse)",
	doc = L["Return Curse if the unit has a Curse debuff"],
	example = ('[HasCurseDebuff] => %q; [HasCurseDebuff] => ""'):format("Curse"),
	category = L["Auras"]
})

DogTag:AddTag("HasPoisonDebuff", {
	alias = "HasDebuffType(Poison)",
	doc = L["Return Poison if the unit has a Poison debuff"],
	example = ('[HasPoisonDebuff] => %q; [HasPoisonDebuff] => ""'):format("Poison"),
	category = L["Auras"]
})

DogTag:AddTag("HasDiseaseDebuff", {
	alias = "HasDebuffType(Disease)",
	doc = L["Return Disease if the unit has a Disease debuff"],
	example = ('[HasDiseaseDebuff] => %q; [HasDiseaseDebuff] => ""'):format("Disease"),
	category = L["Auras"]
})

end
